@@ -3,6 +3,9 @@
 #include <Rcpp.h>
 #include <meteoland.h>
 #include <medfate.h>
+#if SERGHEI_COUPLING
+  #include "/home/miquel/serghei-master/src/MedFateLand_Serghei.h"
+#endif
 using namespace Rcpp;
 using namespace medfate;
 using namespace meteoland;
@@ -561,15 +564,18 @@ List initSerghei(NumericVector limits, int nrow, int ncol,
         uptake[sf2cell[i] - 1] = vup; //indices in R
       }
     }
-  }
+  }  
   // Initialize SERGHEI (call to interface function)
+#if SERGHEI_COUPLING
+  MedFateLand_Serghei::start();
+#endif
   // Use input_dir and output_dir
-  // initializeSerghei(soilListSerghei, uptake, throughfall);
   List serghei_interface = List::create(_["limits"] = limits,
                                         _["dim"] = IntegerVector::create(nrow,ncol),
                                         _["soilList"] = soilListSerghei,
                                         _["throughfall"] = throughfall,
                                         _["uptake"] = uptake);
+  
   return(serghei_interface);
 }
 
@@ -592,7 +598,8 @@ void callSergheiDay(CharacterVector lct, List xList,
     if((lct[i]=="wildland") || (lct[i]=="agriculture")) {
       NumericVector vup = Rcpp::as<Rcpp::NumericVector>(uptakeSerghei[sf2cell[i] - 1]); //indices in R
       // Rcout<<".";
-      List res_i = localResults[i];
+      List loc_res_i = localResults[i];
+      List res_i = loc_res_i["simulation_results"];
       NumericVector DB = res_i["WaterBalance"];
       DataFrame SB = Rcpp::as<Rcpp::DataFrame>(res_i["Soil"]);
       //Copy throughfall
@@ -620,7 +627,9 @@ void callSergheiDay(CharacterVector lct, List xList,
   }
   
   // CALL SERGHEI (call to interface function)
-  
+#if SERGHEI_COUPLING
+  MedFateLand_Serghei::compute_daily_step();
+#endif
   //B.3 - Recover new soil moisture state from SERGHEI, calculate the difference between 
   //SERGHEI and MEDFATE and apply the differences to the soil moisture (overall or water pools)
   for(int i=0;i<nX;i++) {
@@ -656,3 +665,9 @@ void callSergheiDay(CharacterVector lct, List xList,
   }
 }
 
+// [[Rcpp::export(".finishSerghei")]]
+void finishSerghei() {
+#if SERGHEI_COUPLING
+  MedFateLand_Serghei::finalise();
+#endif
+}
